@@ -27,13 +27,17 @@ class Configuration:
     def __init__(self,
                  stream_name: str,
                  iterator_type: IteratorType,
-                 endpoint: typing.Optional[str],
                  delay_in_ms: int,
+                 max_records_per_request: int,
+                 region: typing.Optional[str] = None,
+                 endpoint: typing.Optional[str] = None,
                  ):
-        self.iterator_type = iterator_type
         self.stream_name = stream_name
-        self.endpoint = endpoint
+        self.iterator_type = iterator_type
         self.delay_in_ms = delay_in_ms
+        self.max_records_per_request = max_records_per_request
+        self.region = region
+        self.endpoint = endpoint
 
     def __str__(self) -> str:
         return f'Configuration<stream_name={self.stream_name}>'
