@@ -5,6 +5,7 @@ from _pytest.capture import CaptureFixture
 
 from aws_kinesis_consumer.configuration.configuration import Configuration, IteratorType
 from aws_kinesis_consumer.kinesis.shard import Shard
+from aws_kinesis_consumer.ui.printer import Printer
 
 STREAM_NAME = 'STREAM_NAME'
 SHARD_ID = 'SHARD_ID'
@@ -53,7 +54,7 @@ def test_print_records(capsys: CaptureFixture):
 
     output = capsys.readouterr()
     assert output.err.splitlines() == [
-        '<shard_id=SHARD_ID, records=2>'
+        '> shard_id=SHARD_ID, records=2'
     ]
     assert output.out.splitlines() == [
         'RECORD-1',
@@ -112,7 +113,7 @@ def test_print_records_when_no_records(capsys: CaptureFixture):
 
     # then
     assert capsys.readouterr().err.splitlines() == [
-        '<shard_id=SHARD_ID, records=0>'
+        '> shard_id=SHARD_ID, records=0'
     ]
 
 
@@ -147,8 +148,8 @@ def test_print_records_when_next_shard_iterator_is_none(capsys: CaptureFixture):
 
     # then
     assert capsys.readouterr().err.splitlines() == [
-        '<shard_id=SHARD_ID, records=0>',
-        '<shard iterator is null, the shard seems to be closed, shard_id=SHARD_ID>',
+        '> shard_id=SHARD_ID, records=0',
+        '> shard iterator is null, the shard seems to be closed, shard_id=SHARD_ID',
     ]
 
 
@@ -172,13 +173,12 @@ def create_shard():
     kinesis.get_records.return_value = {'Records': []}
 
     configuration = Configuration(
-        STREAM_NAME,
-        ITERATOR_TYPE,
-        None,
-        DELAY_IN_MILS,
-        MAX_NB_OF_RECORDS,
+        stream_name=STREAM_NAME,
+        iterator_type=ITERATOR_TYPE,
+        delay_in_ms=DELAY_IN_MILS,
+        max_records_per_request=MAX_NB_OF_RECORDS,
     )
 
-    shard = Shard(SHARD_ID, configuration, kinesis)
+    shard = Shard(SHARD_ID, configuration, kinesis, Printer())
 
     return shard, kinesis
